import sys

from django.urls import re_path
from django.http import HttpResponse

from toga import platform


class App:
    def __init__(self, app_module):
        self.app_module = app_module

    def app(self, request, state):
        # Make the Python __main__ context identify as the app being executed.
        sys.modules['__main__'] = self.app_module

        # Set the current platform to be `web`
        platform.current_platform = 'web'

        # Instantiate the app
        app = self.app_module.main()

        # Render the app
        return HttpResponse(
            app._impl.render(
                state=state,
                headers=request.META,
            )
        )

    def get_urls(self):
        urlpatterns = [
            re_path(r'(?P<state>.*)$', self.app, name='app'),
        ]
        return urlpatterns

    @property
    def urls(self):
        return self.get_urls(), 'toga', 'myapp'



#!/usr/bin/env python
import re

from setuptools import setup

# Version handline needs to be programatic because
# we can't import toga_django to compute the version;
# and to support versioned subpackage dependencies
with open('toga_django/__init__.py', encoding='utf8') as version_file:
    version_match = re.search(
        r"^__version__ = ['\"]([^'\"]*)['\"]",
        version_file.read(),
        re.M
    )
    if version_match:
        version = version_match.group(1)
    else:
        raise RuntimeError("Unable to find version string.")

setup(
    version=version,
    description='A Django backend for the Toga widget toolkit.',
    install_requires=[
        'django~=3.0',
        'django-environ==0.4.1',
        'toga-web==%s' % version,
    ],
)
